@@ -4,8 +4,7 @@ use std::fs::create_dir_all;
 use cosmwasm_schema::{export_schema, remove_schemas, schema_for};
 
 use osmo_bindings::{
-    EstimatePriceResponse, FullDenomResponse, OsmosisMsg, OsmosisQuery, PoolStateResponse,
-    SpotPriceResponse,
+    EstimatePriceResponse, OsmosisMsg, OsmosisQuery, PoolStateResponse, SpotPriceResponse,
 };
 
 fn main() {
@@ -16,7 +15,6 @@ fn main() {
 
     export_schema(&schema_for!(OsmosisMsg), &out_dir);
     export_schema(&schema_for!(OsmosisQuery), &out_dir);
-    export_schema(&schema_for!(FullDenomResponse), &out_dir);
     export_schema(&schema_for!(PoolStateResponse), &out_dir);
     export_schema(&schema_for!(SpotPriceResponse), &out_dir);
     export_schema(&schema_for!(EstimatePriceResponse), &out_dir);
