@@ -3,9 +3,7 @@ mod query;
 mod types;
 
 pub use msg::OsmosisMsg;
-pub use query::{
-    EstimatePriceResponse, FullDenomResponse, OsmosisQuery, PoolStateResponse, SpotPriceResponse,
-};
+pub use query::{EstimatePriceResponse, OsmosisQuery, PoolStateResponse, SpotPriceResponse};
 pub use types::{Step, Swap, SwapAmount, SwapAmountWithLimit};
 
 // This is a signal, such that any contract that imports these helpers will only run on the
